Authors
=======
The following have contributed to the development, maintenance, and testing of PyBEL Tools

Maintainer
----------
`Charles Tapley Hoyt <https://github.com/cthoyt>`_

Code Contributors
-----------------
- `Daniel Domingo <https://github.com/ddomingof>`_
- `Andrej Konotopez <https://github.com/lekono>`_
- Reagon Kharki
